package com.ccccly.EZSDK;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.IllegalViewOperationException;
import com.videogo.openapi.EZGlobalSDK;
import com.videogo.openapi.EZOpenSDK;
import com.videogo.openapi.bean.EZDeviceInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by GeekC on 2016/10/25.
 */

public class EZSDKModule extends ReactContextBaseJavaModule {
    private final String moduleName = "EZSDK";
    private List<EZDeviceInfo> deviceList = new ArrayList<>();
    private final String TAG = "EZSDKNativeModule";

    public EZSDKModule(ReactApplicationContext context) {
        super(context);
    }
    @Override
    public String getName() {
        return moduleName;
    }

    @ReactMethod
    public void openLoginPage() {
        EZOpenSDK.getInstance().openLoginPage();
    }

    @ReactMethod
    public void init(String token, ReadableArray deviceSerials) {
        EZOpenSDK.getInstance().setAccessToken(token);
        Intent intent = new Intent("com.videogo.action.OAUTH_SUCCESS_ACTION");
        ArrayList<String> array = new ArrayList<String>();
        for (int i = 0; i < deviceSerials.size(); i++) {
            array.add(deviceSerials.getString(i));
        }
        intent.putExtra("deviceSerials", array);
        getCurrentActivity().sendBroadcast(intent);
    }

    @ReactMethod
    public void getCameraList(String token, final Promise promise) {
        try {
            EZOpenSDK.getInstance().setAccessToken((token));
            new Thread(new Runnable() {
                @Override
                public void run() {
                    try{
                        deviceList = EZOpenSDK.getInstance().getDeviceList(0, 30);
                        WritableArray array = Arguments.createArray();
                        for (int i = 0; i < deviceList.size(); i++) {
                            WritableMap map = Arguments.createMap();
                            EZDeviceInfo device = deviceList.get(i);
                            map.putString("deviceName", device.getDeviceName());
                            map.putString("deviceSerial", device.getDeviceSerial());
                            map.putInt("index", i);
                            map.putBoolean("status", device.getStatus() == 1);
                            array.pushMap(map);
                        }
                        promise.resolve(array);
                    } catch (Exception e) {
                          Log.i(TAG, e.getMessage());
                    }


                }
            }).start();

        } catch (IllegalViewOperationException e) {
            promise.reject(e.getMessage());
        }
    }
    @ReactMethod
    public void play(int index) {
        EZDeviceInfo deviceInfo = deviceList.get(index);
        Intent intent = new Intent("com.videogo.action.PLAY_SELECT_DEVICE");
        intent.putExtra("deviceInfo", deviceInfo);
        getCurrentActivity().sendBroadcast(intent);
    }
}
